<?php

defined('ABSPATH') or die('No direct script access allowed.');


class ExpayPayment
{
    private $provider;
    private $order;

    public function __construct(int $order_id)
    {
        $this->order = wc_get_order($order_id);
        $this->provider = new ExpayProvider();
    }

    function initPayment($payment_methods)
    {
        $attributes = [];
        $methodList = $payment_methods;
        foreach ($methodList as $method) {
            if ($method['alias'] === $_POST['expay-payment-method']) {
                $service_id = $method['id'];
                if (count($method['attributes']) != 0) {
                    foreach ($method['attributes'] as $attribute) {
                        if (!empty($_POST[$attribute['key']])) {
                            $attributes[$attribute['key']] = $_POST[$attribute['key']];
                        }
                    }
                }
                break;
            }
        }

        $response = $this->provider->initPayment(
            $service_id,
            $this->order->get_total(),
            $this->order->get_order_number(),
            $this->order->get_checkout_order_received_url(),
            $this->order->get_checkout_order_received_url(),
            $this->order->get_cancel_order_url_raw($this->order->get_checkout_order_received_url()),
            $attributes
        );

        return $response;
    }


    function getPaymentUrl($response)
    {
        if (count($response['attributes']) != 0) {
            foreach ($response['attributes'] as $attribute) {
                switch ($attribute['key']) {
                    case 'redirectUrl':
                        return [
                            'key' => 'redirectUrl',
                            'src' => $attribute['value'],
                            'name' => $response['service']['name'],
                        ];
                    case 'qrcode':
                        return [
                            'key' => 'qrcode',
                            'src' => $attribute['value'],
                        ];
                    case 'receiptUrl': // PDF
                        return [
                            'key' => 'receiptUrl',
                            'src' => $attribute['value'],
                        ];
                        break;
                    default:
                        break;
                }
            }
        } else {
            return [
                'key' => 'offline',
                'src' => $this->order->get_checkout_order_received_url(),
            ];
        }
    }
}